@@ -44,7 +44,7 @@ has their own advantages and disadvantages over the others.
     relatively simple context managers that don't require defining an actual
     class.
                 
-    This usage is nothing new; It's also available when using the standard
+    This usage is nothing new; it's also available when using the standard
     library's `contextlib.contextmanager` decorator. One thing that is allowed
     here that `contextlib` doesn't allow is to yield the context manager itself
     by doing `yield SelfHook`.
@@ -271,7 +271,7 @@ class ContextManagerType(abc.ABCMeta, metaclass=ContextManagerTypeType):
             # If so, we need to be careful. It's okay for this class to be
             # using the enter/exit pair provided by the base `manage_context`;
             # It's also okay for this class to override these with its own
-            # `__enter__` and `__exit__` implementations; But it's *not* okay
+            # `__enter__` and `__exit__` implementations; but it's *not* okay
             # for this class to define just one of these methods, say
             # `__enter__`, because then it will not have an `__exit__` to work
             # with.
@@ -290,7 +290,7 @@ class ContextManagerType(abc.ABCMeta, metaclass=ContextManagerTypeType):
                 assert '__enter__' in namespace
             
                 raise Exception("The %s class defines an `__enter__` method, "
-                                "but not an `__exit__` method; We cannot use "
+                                "but not an `__exit__` method; we cannot use "
                                 "the `__exit__` method of its base context "
                                 "manager class because it uses the "
                                 "`manage_context` generator function." %
@@ -303,7 +303,7 @@ class ContextManagerType(abc.ABCMeta, metaclass=ContextManagerTypeType):
                 assert '__exit__' in namespace
                 
                 raise Exception("The %s class defines an `__exit__` method, "
-                                "but not an `__enter__` method; We cannot use "
+                                "but not an `__enter__` method; we cannot use "
                                 "the `__enter__` method of its base context "
                                 "manager class because it uses the "
                                 "`manage_context` generator function." %
@@ -396,7 +396,7 @@ class ContextManager(object, metaclass=ContextManagerType):
                    generator_return_value
         
         except StopIteration:
-            raise RuntimeError("The generator didn't yield even one time; It "
+            raise RuntimeError("The generator didn't yield even one time; it "
                                "must yield one time exactly.")
     
         
@@ -417,7 +417,7 @@ class ContextManager(object, metaclass=ContextManagerType):
                 return
             else:
                 raise RuntimeError(
-                    "The generator didn't stop after the yield; Possibly you "
+                    "The generator didn't stop after the yield; possibly you "
                     "have more than one `yield` in the generator function? "
                     "The generator function must yield exactly one time.")
         else:
@@ -449,3 +449,9 @@ class ContextManager(object, metaclass=ContextManagerType):
                     "function? The generator function must yield exactly one "
                     "time."
                 )
+            
+            
+class BlankContextManager(ContextManager):
+    '''A context manager that does nothing.'''
+    def manage_context(self):
+        yield self
