@@ -42,7 +42,7 @@ def get_root_path_of_module(module):
     
     This is the path that should be in `sys.path` for the module to be
     importable. Note that this would give the same answer for
-    `my_package.my_sub_package.my_module` as for `my_package`; It only cares
+    `my_package.my_sub_package.my_module` as for `my_package`; it only cares
     about the root module.
     '''
     assert isinstance(module, types.ModuleType)
