@@ -7,7 +7,7 @@ Defines the `count_calls` decorator.
 See its documentation for more details.
 '''
 
-from garlicsim.general_misc.third_party import decorator as decorator_module
+from garlicsim.general_misc import decorator_tools
 
 
 def count_calls(function):
@@ -39,7 +39,7 @@ def count_calls(function):
         decorated_function.call_count += 1
         return function(*args, **kwargs)
     
-    decorated_function = decorator_module.decorator(_count_calls, function)
+    decorated_function = decorator_tools.decorator(_count_calls, function)
     
     decorated_function.call_count = 0
     
