@@ -25,7 +25,7 @@ def call_and_check_if_profiled(f):
     segments_found = [(segment in output) for segment in segments]
     
     if not logic_tools.all_equal(segments_found):
-        raise Exception("Some segments were found, but some weren't; Can't "
+        raise Exception("Some segments were found, but some weren't; can't "
                         "know if this was a profiled call or not. Possibly "
                         "some of our segments are wrong.")
     
